@@ -25,20 +25,19 @@ class DeleteFaceEntityRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'facebody', '2019-12-30', 'DeleteFaceEntity','facebody')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_EntityId(self):
+	def get_EntityId(self): # String
 		return self.get_body_params().get('EntityId')
 
-	def set_EntityId(self,EntityId):
+	def set_EntityId(self, EntityId):  # String
 		self.add_body_params('EntityId', EntityId)
-
-	def get_DbName(self):
+	def get_DbName(self): # String
 		return self.get_body_params().get('DbName')
 
-	def set_DbName(self,DbName):
-		self.add_body_params('DbName', DbName)
\ No newline at end of file
+	def set_DbName(self, DbName):  # String
+		self.add_body_params('DbName', DbName)
