@@ -25,20 +25,19 @@ class DeleteFaceRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'facebody', '2019-12-30', 'DeleteFace','facebody')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_FaceId(self):
+	def get_FaceId(self): # String
 		return self.get_body_params().get('FaceId')
 
-	def set_FaceId(self,FaceId):
+	def set_FaceId(self, FaceId):  # String
 		self.add_body_params('FaceId', FaceId)
-
-	def get_DbName(self):
+	def get_DbName(self): # String
 		return self.get_body_params().get('DbName')
 
-	def set_DbName(self,DbName):
-		self.add_body_params('DbName', DbName)
\ No newline at end of file
+	def set_DbName(self, DbName):  # String
+		self.add_body_params('DbName', DbName)
