@@ -25,7 +25,19 @@ class ListFaceDbsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'facebody', '2019-12-30', 'ListFaceDbs','facebody')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+	def get_Limit(self): # Long
+		return self.get_body_params().get('Limit')
+
+	def set_Limit(self, Limit):  # Long
+		self.add_body_params('Limit', Limit)
+	def get_Offset(self): # Long
+		return self.get_body_params().get('Offset')
+
+	def set_Offset(self, Offset):  # Long
+		self.add_body_params('Offset', Offset)
