@@ -25,36 +25,33 @@ class RecognizeActionRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'facebody', '2019-12-30', 'RecognizeAction','facebody')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Type(self):
+	def get_Type(self): # Integer
 		return self.get_body_params().get('Type')
 
-	def set_Type(self,Type):
+	def set_Type(self, Type):  # Integer
 		self.add_body_params('Type', Type)
-
-	def get_VideoData(self):
+	def get_VideoData(self): # String
 		return self.get_body_params().get('VideoData')
 
-	def set_VideoData(self,VideoData):
+	def set_VideoData(self, VideoData):  # String
 		self.add_body_params('VideoData', VideoData)
-
-	def get_URLLists(self):
+	def get_URLLists(self): # RepeatList
 		return self.get_body_params().get('URLList')
 
-	def set_URLLists(self, URLLists):
-		for depth1 in range(len(URLLists)):
-			if URLLists[depth1].get('imageData') is not None:
-				self.add_body_params('URLList.' + str(depth1 + 1) + '.imageData', URLLists[depth1].get('imageData'))
-			if URLLists[depth1].get('URL') is not None:
-				self.add_body_params('URLList.' + str(depth1 + 1) + '.URL', URLLists[depth1].get('URL'))
-
-	def get_VideoUrl(self):
+	def set_URLLists(self, URLList):  # RepeatList
+		for depth1 in range(len(URLList)):
+			if URLList[depth1].get('imageData') is not None:
+				self.add_body_params('URLList.' + str(depth1 + 1) + '.imageData', URLList[depth1].get('imageData'))
+			if URLList[depth1].get('URL') is not None:
+				self.add_body_params('URLList.' + str(depth1 + 1) + '.URL', URLList[depth1].get('URL'))
+	def get_VideoUrl(self): # String
 		return self.get_body_params().get('VideoUrl')
 
-	def set_VideoUrl(self,VideoUrl):
-		self.add_body_params('VideoUrl', VideoUrl)
\ No newline at end of file
+	def set_VideoUrl(self, VideoUrl):  # String
+		self.add_body_params('VideoUrl', VideoUrl)
