@@ -25,32 +25,29 @@ class VerifyFaceMaskRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'facebody', '2019-12-30', 'VerifyFaceMask','facebody')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_RefData(self):
+	def get_RefData(self): # String
 		return self.get_body_params().get('RefData')
 
-	def set_RefData(self,RefData):
+	def set_RefData(self, RefData):  # String
 		self.add_body_params('RefData', RefData)
-
-	def get_ImageData(self):
+	def get_ImageData(self): # String
 		return self.get_body_params().get('ImageData')
 
-	def set_ImageData(self,ImageData):
+	def set_ImageData(self, ImageData):  # String
 		self.add_body_params('ImageData', ImageData)
-
-	def get_ImageURL(self):
+	def get_ImageURL(self): # String
 		return self.get_body_params().get('ImageURL')
 
-	def set_ImageURL(self,ImageURL):
+	def set_ImageURL(self, ImageURL):  # String
 		self.add_body_params('ImageURL', ImageURL)
-
-	def get_RefUrl(self):
+	def get_RefUrl(self): # String
 		return self.get_body_params().get('RefUrl')
 
-	def set_RefUrl(self,RefUrl):
-		self.add_body_params('RefUrl', RefUrl)
\ No newline at end of file
+	def set_RefUrl(self, RefUrl):  # String
+		self.add_body_params('RefUrl', RefUrl)
